<?php
/**
* @package		EasySocial
* @copyright	Copyright (C) 2010 - 2019 Stack Ideas Sdn Bhd. All rights reserved.
* @license		GNU/GPL, see LICENSE.php
* EasySocial is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/
defined('_JEXEC') or die('Unauthorized Access');

ES::import('admin:/includes/fields/dependencies');

class SocialFieldsEventBlogcreate extends SocialFieldItem
{
	public function exists()
	{
		$file = JPATH_ROOT . '/administrator/components/com_easyblog/includes/easyblog.php';

		if (!JFile::exists($file)) {
			return false;
		}

		require_once($file);

		return true;
	}

	public function onRegister(&$post, &$session)
	{
		if (!$this->exists()) {
			return;
		}

		$value = !empty($post['blogcreate']) ? $post['blogcreate'] : '[]';

		$value = ES::makeArray($value);
		$checkboxForm = $this->getCheckboxForm($value);

		$this->set('value', $value);
		$this->set('checkboxForm', $checkboxForm);

		return $this->display();
	}

	public function onEdit(&$post, &$event, $errors)
	{
		if (!$this->exists()) {
			return;
		}

		$value = !empty($post['blogcreate']) ? $post['blogcreate'] : $event->getParams()->get('blogcreate', '[]');

		$value = ES::makeArray($value);
		$checkboxForm = $this->getCheckboxForm($value);

		$this->set('value', $value);
		$this->set('checkboxForm', $checkboxForm);

		return $this->display();
	}

	public function getCheckboxForm($value)
	{
		$defaultOptions = array('admin', 'member');
		$checkboxOptions = $this->params->get('create_options');

		if (!$checkboxOptions) {
			$checkboxOptions = $defaultOptions;
		}

		if (empty($value)) {
			$value = $this->params->get('create_default');
		}

		$checkboxForm = array();

		foreach ($checkboxOptions as $checkbox) {

			if ($checkbox == 'owner') {
				continue;
			}

			$obj = new stdClass();
			$obj->name = $checkbox;
			$obj->selected = !empty($value) && in_array($checkbox, $value) ? true : false;

			$checkboxForm[] = $obj;
		}

		return $checkboxForm;
	}

	public function onRegisterBeforeSave(&$post, &$event)
	{
		return $this->onBeforeSave($post, $event);
	}

	public function onEditBeforeSave(&$post, &$event)
	{
		return $this->onBeforeSave($post, $event);
	}

	public function onBeforeSave(&$post, &$event)
	{
		$value = !empty($post['blogcreate']) ? $post['blogcreate'] : '[]';

		// Pre-fill the default value
		$defaultOptions = array('admin', 'member');
		$checkboxOptions = $this->params->get('create_options');

		$value = ES::makeArray($value);
		$defaultValue = $this->params->get('create_default');
		$defaultValue = array_flip($defaultValue);

		if ($checkboxOptions) {
			foreach ($defaultOptions as $option) {
				if (!isset($checkboxOptions[$option])) {
					if (isset($defaultValue[$option])) {
						$value[] = $option;
					}
				}
			}
		}

		$params = $event->getParams();
		$params->set('blogcreate', ES::makeArray($value));

		$event->params = $params->toString();

		unset($post['blogcreate']);
	}
}